#coding: utf-8
from django.core.management.base import BaseCommand, CommandError
from django.db.models import Count
from avisstage.models import Stage, Lieu

class Command(BaseCommand):
    help = 'Nettoie les stages à plusieurs lieux identiques'

    def add_arguments(self, parser):
        parser.add_argument('min_stage', nargs='?', default=0, type=int)
        parser.add_argument(
            '--apply',
            action='store_true',
            default=False,
            help='Applies the modifications',
        )

    def handle(self, *args, **options):
        def get_len(obj):
            length = 0
            avis = obj.avis_all
            for k, av in avis:
                length += len(av.split())
            length += len(obj.chapo.split())
            length += len(obj.les_plus.split())
            length += len(obj.les_moins.split())
            return length

        rundb = False
        if options.get('apply', False):
            rundb = True
        else:
            print u"Les modifications ne seront pas appliquées"
            
        min_stage = options.get('min_stage', 0)

        for stage in Stage.objects.annotate(c=Count("lieux"))\
                                  .filter(c__gte=2, id__gte=min_stage):
            lieuset = {}
            todel = []
            problems = []
            for avis in stage.avislieu_set.all():
                alen = get_len(avis)
                aid = avis.lieu.id
                if aid in lieuset:
                    if alen == 0:
                        todel.append((avis, alen))
                        continue
                    elif lieuset[aid][1] == 0:
                        todel.append(lieuset[aid])
                    else:
                        problems += [(avis, alen), lieuset[aid]]
                lieuset[aid] = (avis, alen)
            if len(todel) > 0:
                print u"Doublons détectés dans %s" % (stage,)
                for avis, alen in todel:
                    print u" > Suppression de l'avis sur %s de %d mots" % \
                        (avis.lieu, alen)
                    if rundb:
                        avis.delete()
            if len(problems) > 0:
                self.stdout.write(self.style.WARNING(u"Réparation impossible de %s (id=%d)" % (stage, stage.id)))
                for avis, alen in problems:
                    print u" > Avis sur %s de %d mots" % \
                        (avis.lieu, alen)
        self.stdout.write(self.style.SUCCESS(u'Nettoyage des stages effectué'))
