function InterfaceRecherche(STATIC_ROOT, API_LIEU, lieux) {
    var interface_mode, main_container;
    var lieux_map = {}, lieux_list = [], stages_map = {}, lieux_db = {};
    var stages_data = {};
    var marqueurs = L.markerClusterGroup();
    var marqueurs_db = {};
    var changevue;
    var details_lock = false;
    var map, lieux_survol;
    var stage_focused;

    // Initialisation globale de l'interface et du switch liste / hybride / carte
    // TODO se souvenir des préférences d'affichage
    
    function initInterface() {
        main_container = $(".content.recherche");
        if (main_container.hasClass("vue-liste")) {
            interface_mode = "liste";
        } else if (main_container.hasClass("vue-carte")) {
            interface_mode = "carte";
        } else {
            interface_mode = "hybride";
        }

        changevue = $(".vue-options");
        $.each(changevue.find('a'), function(i, item) {
            $(item).on('click', btnChangeInterface);
        });

        $.each(lieux, function(i, item) {
            var stage_id = item[0];
            var lieu_id = item[1];
            if (lieux_map[lieu_id] === undefined) {
                lieux_map[lieu_id] = [];
                lieux_list.push(lieu_id);
            }
            lieux_map[lieu_id].push(stage_id);
            
            if (stages_map[stage_id] === undefined) {
                stages_map[stage_id] = [];
            }
            stages_map[stage_id].push(lieu_id);
        });
        
        changeInterface(interface_mode);
    }

    // Changement d'affichage : mise à jour des classes et démarrage de la carte si nécessaire
    
    function btnChangeInterface() {
        changeInterface(this.id.split('_')[1]);
    }
    
    function changeInterface(mode) {
        interface_mode = mode;
        $(".content.recherche").removeClass("vue-carte vue-hybride vue-liste")
                               .addClass("vue-"+mode);
        if (mode=="hybride" || mode=="carte") {
            initCarte();
            map.invalidateSize();
        }
    }

    // Carte

    function initCarte() {
        if (map !== undefined) return;
        map = L.map("carte").panTo([30, 15]).setZoom(1);
        var layer = new L.TileLayer("https://korona.geog.uni-heidelberg.de/tiles/roads/x={x}&y={y}&z={z}", {attribution: 'Map tiles by <a href="http://korona.geog.uni-heidelberg.de/">GIScience Heidelberg</a>'});
        map.addLayer(layer);

        $.getJSON(API_LIEU + "set/"+lieux_list.join(';')+"/?format=json", onLoadLieux);
    }
    
    function makeIcon(couleur, scale){
        if (scale===undefined) scale = 1;
        return L.icon({
            iconUrl: STATIC_ROOT + 'images/marker-'+couleur+'.png',
            iconSize: [36 * scale, 46 * scale],
            iconAnchor: [18 * scale, 45 * scale],
            popupAnchor: [0, -48]
        })
    }
    var greenIcon = makeIcon('red');
    var blueIcon = makeIcon('blue', 1.2);

    // Chargeùent des infos
    function onLoadLieux(data){
        console.log(data);
        var lieux = data.objects;
        var bds = [];
        $.each(lieux, function(i, item) {
            var marqueur = L.marker(item.coord, {icon: greenIcon});
            bds.push(item.coord);
            var txt = item.num_stages > 1 ? item.num_stages+" stages ici": "1 stage ici";
            txt = "<h3>"+item.nom+"</h3>"+
                  "<p>"+txt+"</p>";
            marqueur.bindPopup(txt + "<p>Chargement...</p>");
            marqueurs.addLayer(marqueur);
            marqueur.on("popupopen", showDetailLieu)
                    .on("popupclose", unlockDetailsListe)
                    .on("mouseover", showDetailsListeListener)
                    .on("mouseout", hideDetailsListeListener);
            marqueur._lieu_data = item;
            marqueur._popup_header = txt;
            marqueur._lieu_data_loading = false;
            marqueurs_db[item.id] = marqueur;
            lieux_db[item.id] = item;
        });
        map.addLayer(marqueurs);
        lieux_survol = new L.layerGroup();
        map.addLayer(lieux_survol);

        map.fitBounds(bds, {maxZoom: 11});
        $("#liste-resultats .stage")
            .on("mouseover touchdown", showLieuxFromStage)
            .on("mouseout", hideLieuxSurvol);
        $("#liste-resultats")
            .on("touchdown", hideLieuxSurvol);
    }


    //
    // Actions sur la carte -> Affichage réduit de la liste des stages
    //
    
    function showDetailLieu () {
        // Affichage du popup détaillé
        var data = this._lieu_data;
        showDetailsListe(data);
        details_lock = data;
        var marqueur = marqueurs_db[data.id];
        var html = $("<div>").html(marqueur._popup_header);
        var stageliste = $("<ul>");
        $.each(lieux_map[data.id], function(i, item) {
            var stage_el = $("#resultat-stage-"+item);
            var url = stage_el.find('a.stage-sujet').attr('href');
            var sujet = stage_el.find('a.stage-sujet').text();
            var auteur = stage_el.find('.auteur').text();
            var stage = $("<li>")
                .append($("<a>", {href: url}).text(sujet))
                .append($("<span>").text(" par "+auteur));
            stageliste.append(stage);
        });
        html.append(stageliste);
        marqueur.setPopupContent(html[0]);
    }

    function showDetailsListeListener (evt) {
        showDetailsListe(this._lieu_data);
    }

    function showDetailsListe (data) {
        main_container.addClass("vue-details");
        var liste_el = $("#resultats-details");
        $.each(liste_el.children(), function(i, item){$(item).remove();});
        $.each(lieux_map[data.id], function(i, item) {
            var stage_el = $("#resultat-stage-"+item);
            var new_el = $("<li>", {class:"stage"}).html(stage_el.html());
            liste_el.append(new_el);
        });
    }

    function unlockDetailsListe () {
        details_lock = false;
        hideDetailsListeListener();
    }
    
    function hideDetailsListeListener () {
        if (details_lock === false)
            main_container.removeClass("vue-details");
        else
            showDetailsListe(details_lock);
    }

    //
    // Survol dans la liste -> Affichage des lieux
    //
    
    function showLieuxFromStage (evt) {
        if (stages_map === undefined) return;
        hideLieuxSurvol();
        var stageid = this.id.split("-")[2];
        var lieuxids = stages_map[stageid];
        $.each(lieuxids, function(i, lieu_id) {
            var data = lieux_db[lieu_id];
            var marqueur = new L.marker(data.coord, {icon:blueIcon});
            lieux_survol.addLayer(marqueur);
        });
        $(this).addClass("expanded");
    }

    function hideLieuxSurvol () {
        lieux_survol.clearLayers();
        $("li.stage.expanded").removeClass("expanded");
    }

    // __init__
    
    initInterface();
}
