$(function() {
    var RADIUS = 37;

    // $("<...>", {}) pour des éléments SVG (i.e. namespacés)
    function cElSVG(name, props) {
        var el = document.createElementNS("http://www.w3.org/2000/svg", name);
        for (var n in props)
            el.setAttribute(n, props[n]);

        return el;
    }

    // Rendu des dates de stage
    function renderDateClock(item) {
        var $el = $(item);

        // Parsing dates
        var debut = $el.find(".debut").text().split("/");
        var fin = $el.find(".fin").text().split("/");
        var an = $el.find(".year").text();
        var scale = 1;
        if($el.attr("c-radius"))
            scale = Number($el.attr("c-radius")) / RADIUS;

        // Conteneurs
        var svg = cElSVG("svg");
        svg.setAttribute('x', -(RADIUS+3)*scale);
        svg.setAttribute('y', -(RADIUS+3)*scale);
        svg.setAttribute("width", 2*(RADIUS+3)*scale);
        svg.setAttribute("height", 2*(RADIUS+3)*scale);
        var g = cElSVG("g", {"transform":"scale("+scale+")"+
                                         "translate("+(3+RADIUS)+", "+(3+RADIUS)+")"});

        // FOND
        // Mois
        var ticks = [];
        for (var a=0; a<12; a++) {
            var ang = (a/6+0.5)*Math.PI;
            ticks.push("M",
                       (RADIUS-4)*Math.cos(ang),
                       (RADIUS-4)*Math.sin(ang),
                       "L",
                       (RADIUS)*Math.cos(ang),
                       (RADIUS)*Math.sin(ang),);
        }
        var svg_tks = cElSVG("path",
                             {"d": ticks.join(" "), "stroke":"#ffffff99",
                              "stroke-width": 1, "fill": "none"});
        $(g).append(svg_tks);

        // Cercle
        var svg_fnd = cElSVG("circle",
                             {"cx": 0, "cy":0, "r":RADIUS, "stroke":"#ffffff99",
                              "stroke-width": 1, "fill": "none"});
        $(g).append(svg_fnd);

        // Période du stage
        console.log(debut, fin);
        var peri = [];
        var bo = Number(debut[1])-1+(Number(debut[0])-1)/30;
        bo = bo/6+0.5;
        var bf = Number(fin[1])-1+(Number(fin[0])-1)/30;
        bf = bf/6+0.5;
        console.log(bo, bf);
        peri = ["M",
                RADIUS*Math.cos(bo*Math.PI),
                RADIUS*Math.sin(bo*Math.PI),
                "A",
                RADIUS, RADIUS, 0, (bf-bo>1) ? 1:0, 1,
                RADIUS*Math.cos(bf*Math.PI),
                RADIUS*Math.sin(bf*Math.PI)]
        var svg_peri = cElSVG("path",
                              {"d": peri.join(" "), "stroke":"#ffffff",
                               "stroke-width": 4, "fill": "none"});
        $(g).append(svg_peri);

        // TEXTES
        // Début
        var dtext = cElSVG("text",
                           {"transform":"translate(0, "+(-RADIUS*0.27)+")",
                            "text-anchor":"middle", "class":"debut",
                            "fill":"#fff",
                            "dominant-baseline":"text-after-edge"});
        dtext.innerHTML = debut.join("/");
        $(g).append(dtext);

        // Fin
        var ftext = cElSVG("text",
                           {"transform":"translate(0, "+(RADIUS*0.27)+")",
                            "text-anchor":"middle", "class":"fin",
                            "fill":"#fff",
                            "dominant-baseline":"text-before-edge"});
        ftext.innerHTML = fin.join("/");
        $(g).append(ftext);

        // Année
        var atext = cElSVG("text",
                           {"transform":"translate(0, 3)",
                            "text-anchor":"middle", "class":"year",
                            "fill":"#fff",
                            "dominant-baseline":"middle"});
        atext.innerHTML = an;
        $(g).append(atext);

        // Affichage
        $(svg).append(g);
        $el.html("");
        $el.append(svg);
    }

    function progressiveForEach(array, fun, step, timeout) {
        array = array.slice(); // copie
        var i = 0;
        
        function doLoop(){
            for(var d=0; d<step; i++, d++) {
                if(i>=array.length) return;
                fun(array[i]);
            }
            setTimeout(doLoop, step);
        }
        doLoop();
    }
    progressiveForEach($(".dates"), renderDateClock, 10, 100);

});
