function SelectLieuWidget(STATIC_ROOT, API_LIEU, target, callback) {

    //
    // INITIALISATION
    //
    
    // Éléments d'interface à construire
    var map, input, autocomplete, map_el;
    
    // Éléments d'interface déjà présents
    var $el = $(target);
    var ui_el = $el.find('.lieu-ui');
    var form_el = $el.find('form');
    var content_el = $el.find('.window-content');
    var message_el = $el.find(".lieu-message");
    var closer = $el.find(".window-closer");
    var cmodif_el = $el.find(".lieu-choixmodif");
    var marqueurs = L.markerClusterGroup();

    // Variables globales
    var ui_ready = false;
    var lieux_db = {};
    var ui_mode_creation = true;
    var modiflieu_id;
    var form_marqueur;

    // TODO : icônes mieux gérées
    function makeIcon(couleur){
        return L.icon({
            iconUrl: STATIC_ROOT + 'images/marker-'+couleur+'.png',
            iconSize: [36, 46],
            iconAnchor: [18, 45],
            popupAnchor: [0, -48]
        })
    }
    var greenIcon = makeIcon('green');
    var redIcon = makeIcon('red');
    var blueIcon = makeIcon('blue');

    // Cache le formulaire d'édition
    form_el.detach();
    form_el.on("submit", sendForm);

    // Initialise l'interface
    function initUI(){
        ui_ready = true;
        // Suppression de l'interface déjà existante (au cas où)
        $.each(ui_el.children(), function(i, item){$(item).remove();});

        // Éléments de recherche
        map_el = $("<div>", {class: "map"});
        input = $("<input>",
                  {type:"text",
                   placeholder:"Chercher un établissement...",
                   class:"lieu-acinput"});
        
        ui_el.append(input);
        ui_el.append(map_el);

        // Affiche la carte
        map = L.map(map_el[0]).setView([48.8422411,2.3430553], 15);
        var layer = new L.TileLayer("https://korona.geog.uni-heidelberg.de/tiles/roads/x={x}&y={y}&z={z}", {attribution: 'Map tiles by <a href="http://korona.geog.uni-heidelberg.de/">GIScience Heidelberg</a>'});
        map.addLayer(layer);
        map.addLayer(marqueurs);
        
        // Autocomplete
        autocomplete = new google.maps.places.Autocomplete(input[0]);
        autocomplete.setTypes(["geocode", "establishment"]);

        // Évènements
        closer.on("click", closeWidget).attr("href", "javascript:void(0);");
        $el.find(".window-bg").on("click", closeWidget);
        
        autocomplete.addListener('place_changed', handlePlaceSearch);
        
        cmodif_el.find(".lieu-choixedit").on("click", modifEditLieu);
        cmodif_el.find(".lieu-choixautre").on("click", modifChoixLieu);        
    }

    // Change l'interface selon les besoins
    function setUIMode(mode) {
        $el.removeClass("ajout edit modif attente");
        map.invalidateSize();
        switch(mode) {
            case "select":
            case "change":
                $el.addClass("select");
                break;
            case "ajout":
            case "edit":
                $el.addClass("edit");
                break;
            case "modif":
                $el.addClass("modif");
                break;
            case "attente":
                $el.addClass("attente");
                break;
        }
    }

    // Messages
    function showMessage(message) {
        content_el.find(".message").text(message);
        content_el.find(".message").removeClass("hidden");
    }
    
    function hideMessage() {
        content_el.find(".message").addClass("hidden");
    }
    
    //
    // Carte et autocomplete
    //
    
    // Callback de l'autocomplete
    function handlePlaceSearch() {
        var place = autocomplete.getPlace();
        if (!place.geometry) {
            return;
        }
        console.log(place);
        
        if (lieux_db.suggestion !== undefined) {
            marqueurs.removeLayer(lieux_db.suggestion.marqueur);
            lieux_db.suggestion = undefined;
        }
        
        // Lecture du lieu
        var data = {};
        $.each(place.address_components, function(i, obj) {
            for (var j=0; j<obj.types.length; j++) {
                switch(obj.types[j]) {
                    case "locality":
                        data.ville = obj.long_name;
                        break;
                    case "country":
                        data.pays = obj.short_name;
                        data.pays_nom = obj.long_name;
                        break;
                }
            }
        });
        data.nom = place.name;
        data.coord = {lng: place.geometry.location.lng(),
                      lat: place.geometry.location.lat()};
        data.orig_coord = data.coord;
        data.fromSuggestion = true;
        
        lieux_db.suggestion = data;
        
		map.panTo(data.coord);
        lieuSurCarte(data, redIcon);
        
        // Affichage des suggestions
        askForSuggestions(place.geometry.location);
    }

    // Recherche des données en mémoire
    function askForSuggestions (location) {
        showMessage("Recherche de lieux déjà connus à proximité...");
        $.getJSON(API_LIEU, {"format":"json",
                                    "lat":location.lat,
                                    "lng":location.lng}, showPropositions);
    }

    // Callback suggestions
    function showPropositions(data) {
        showMessage("Cliquez sur un des lieux déjà existants (en bleu) pour le choisir, ou sur votre recherche (en rouge) pour créer un nouveau lieu");

        // Affichage sur la carte
        $.each(data.objects, function(i, item) {
            var plieu = lieux_db[item.id];
            if(plieu !== undefined)
                item = plieu;
            else
                lieux_db[item.id] = item;
            lieuSurCarte(item, blueIcon);
        });
    }

    // Affiche un lieu sur la carte
    function lieuSurCarte(data, icone) {
        // data : des données sur un lieu, sérialisé comme par tastypie

        // Affiche la carte
        map_el.removeClass("masked");
        
        // Si le marqueur est déjà présent : on ne fait rien
        if(data.marqueur !== undefined && marqueurs.hasLayer(data.marqueur))
            return;
        
        var fromSuggestion = false;
        // Si c'est un résultat d'autocomplete
        if(data.fromSuggestion === true)
            fromSuggestion = true;
        
        var marqueur = L.marker(data.coord,
                                {icon: icone, draggable: fromSuggestion});

        data.marqueur = marqueur;
        
        // Création de la description
        var desc = $("<div>").append($("<h3>").text(data.nom))
                             .append($("<p>").text(data.ville+", "+data.pays_nom));
        if (data.num_stages !== undefined)
            desc.append($("<p>").text(data.num_stages + (data.num_stages > 1 ? " stages" : " stage") + " à cet endroit"));
        
        var activeBtn = $("<a>", {href:"javascript:void(0);"})
            .prop("_lieustage_data", data)
            .on("click", choixLieuStage);
        
        if(!fromSuggestion) {
            activeBtn.text("Choisir ce lieu");
        } else {
            var resetBtn = $("<a>", {href:"javascript:void(0);"})
                .text("Réinitialiser la position")
                .prop("_lieustage_data", data)
                .on("click", resetOrigLieu);
            desc.append($("<p>").append(resetBtn))
            activeBtn.text("Créer un nouveau lieu ici");
        }
        desc.append($("<p>").append(activeBtn));
        
        marqueur.bindPopup(desc[0]).addTo(marqueurs);
    }

    // Remet le marqueur à sa place originale (s'il a été déplacé)
    function resetOrigLieu() {
        var data = this._lieustage_data;
        data.marqueur.setLatLng(data.orig_coord);
        map.panTo(data.orig_coord);
    }

    //
    // EDITION
    //

    // Affichage du formulaire
    function showForm(choix, modification) {
        lieux_db.lieufocus = choix;
        content_el.append(form_el);
        form_el.find("#id_nom").val(choix.nom);
        form_el.find("#id_ville").val(choix.ville);
        form_el.find("#id_pays").val(choix.pays);
        form_el.find("#id_coord_0").val(choix.coord.lat);
        form_el.find("#id_coord_1").val(choix.coord.lng);
        if (modification == true) {
            setUIMode("ajout");
            form_el.find("#id_id").val(choix.id);
            form_el.find("h3").text("Modifier un lieu");
        } else {
            setUIMode("edit");
            form_el.find("#id_id").val('');
            form_el.find("h3").text("Créer un lieu");
        }
    }

    // Envoi du formulaire
    function sendForm() {
        setUIMode("attente");
        var coord = lieux_db.lieufocus.marqueur.getLatLng();
        form_el.find("#id_coord_0").val(coord.lat);
        form_el.find("#id_coord_1").val(coord.lng);
        $.post(form_el.attr("action"),
               form_el.serialize(),
               onFormSent);
        form_el.detach();
        showMessage("Envoi en cours...");
        return false;
    }

    function onFormSent(data) {
        console.log(data);
        if(data.success == false) {
            setUIMode("edit");
            content_el.find(".message").text("Erreur : "+data.errors);
            content_el.append(form_el);
        } else {
            // Effacement des données (potentiellement) obsolètes
            if(lieux_db.lieufocus.id !== undefined) {
                lieux_db[lieux_db.lieufocus.id] = undefined;
            }
            lieux_db.lieufocus.id = data.id;
            lieux_db.lieufocus.nom = form_el.find("#id_nom").val();
            callback(lieux_db.lieufocus);
        }
    }

    //
    // MODIFICATION
    //
    // Callback : quand le lieu à modifier est chargé
    function setLieuModif(data) {
        setUIMode("modif")
        hideMessage();
        cmodif_el.find(".lieu-choixrappel").text(data.nom);
        
        // Préparation de la carte
        lieux_db[data.id] = data;
    }

    // Modifier simplement les infos du lieu
    function modifEditLieu() {
        setUIMode("edit");
        var lieu = lieux_db[modiflieu_id];

        lieu.fromSuggestion = true;
        map.panTo(lieu.coord);
        lieuSurCarte(lieu, greenIcon);
                
        showForm(lieu, true);
    }

    // Choisir un autre lieu
    function modifChoixLieu() {
        setUIMode("change");
        var lieu = lieux_db[modiflieu_id];

        lieu.fromSuggestion = false;
        map.panTo(lieu.coord);
        lieuSurCarte(lieu, greenIcon);
        
        askForSuggestions(lieu.coord);
    }


    // Méthodes publiques : affichage de la fenêtre
    this.showWidget = function(lieu_id) {
        // Mise en place de l'interface
        if(!ui_ready)
            initUI();

        input.val('');
        
        // Nettoyage
        hideMessage();

        $el.addClass("visible");
        setUIMode("default");
        form_el.detach();

        // Adaptation à la demande
        if (lieu_id === undefined) {
            // Choix d'un nouveau lieu : pas grand-chose à faire
            ui_mode_creation = true;
            $el.find("h3").text("Ajouter un lieu");
            map_el.addClass("masked");
        } else {
            // Lieu déjà existant
            lieu_id = lieu_id * 1;
            ui_mode_creation = false;
            modiflieu_id = lieu_id;
            $el.find("h3").text("Modifier le lieu");

            // Chargement des infos
            if(lieux_db[lieu_id] === undefined) {
                $.getJSON(API_LIEU + lieu_id + "/?format=json",
                          setLieuModif);
                showMessage("Chargement...");
            } else {
                setLieuModif(lieux_db[lieu_id]);
            }
        }
    }

    // Fermeture du widget
    function closeWidget () {
        $el.removeClass("visible");
    }
    this.closeWidget = closeWidget;

    // Le lieu est choisi, on appelle le callback
    function choixLieuStage() {
        var choix = this._lieustage_data;
        if(!choix.fromSuggestion)
            callback(choix);
        else
            showForm(choix);
    }
}
